# Objet du script :
# Mesure les accélérations suivant 3 axes orthogonaux (en mg) toutes les 20 millisecondes. 
# Utilise cette mesure pour évaluer l'inclinaison du plan de l'accéléromètre par rapport au plan horizontal (tilt)
# Source : Freescale AN3461 rev 2 (page 4)
# Cet exemple nécessite un accéléromètre MEMS LIS2DW12.

from machine import I2C # Pilote pour le bus I2C
import lis2dw12 # Pilote de l'accéléromètre
from time import sleep_ms # Pour temporiser
from math import sqrt, atan, pi # Fonctions et constantes trigonométriques

# Facteur de conversion entre les radians et les degrés pour les angles
RadToDeg = 180 / pi

# On utilise l'I2C n°1 de la carte NUCLEO-WB55 pour communiquer avec le capteur
i2c = I2C(1) 

# Pause d'une seconde pour laisser à l'I2C le temps de s'initialiser
sleep_ms(1000)

# Instanciation de l'accéléromètre
accelerometer = lis2dw12.LIS2DW12(i2c)

# Valeurs initiales des angles
phi = 0
rho = 0
theta = 0
last_phi = phi
last_rho = rho
last_theta = theta

# Seuil de détection des mouvements (°)
ANGLE_TH = (1.5) # Un degré et demi

while True:

	# Mesure des accélération
	ax = accelerometer.x()
	ay = accelerometer.y()
	az = accelerometer.z()

	# Angle entre l'axe des x et le sol
	denom = sqrt(ax*ax + az*az)
	if denom: # équivalent à if denom != 0:
		phi = atan(ay/denom) * RadToDeg

	# Angle entre l'axe des y et le sol
	denom = sqrt(ay*ay + az*az)
	if denom:  # équivalent à if denom != 0:
		theta = atan(ax/denom) * RadToDeg
			
	# Angle entre l'axe des z et la verticale
	if az:  # équivalent à if az != 0
		rho = atan(sqrt(ax*ax + ay*ay)/az) * RadToDeg

	# Si l'un au moins des trois angles a varié de plus que ANGLE_TH degrés depuis la dernière mesure
	# met à jour l'affichage
	if abs(rho-last_rho) > ANGLE_TH or abs(theta-last_theta) > ANGLE_TH or abs(phi-last_phi) > ANGLE_TH:
		print("Angle entre l'axe des x et le plan horizontal : %d°" % phi)
		print("Angle entre l'axe des y et le plan horizontal : %d°" % theta)
		print("Angle entre l'axe des z et la direction verticale : %d°" % rho)
		print("")

	# Mémorisation des angles pour l'itération suivante 
	last_phi = phi
	last_rho = rho
	last_theta = theta
	
	# Temporisation de 20 ms
	sleep_ms(20)