# Objet du script :
# Mesure le champ magnétique selon 3 axes orthogonaux (en µT) toutes les 
# secondes et calcule son intensité (son module).
# Nécessite un magnétomètre MEMS LIS2MDL 
# (par exemple celui du shield X-NUCLEO IKS01A3).
# Intensité du champ terreste : 30µT à 60µT (en théorie)

# Importation des fonctions nécessaires
from machine import I2C
import lis2mdl
from time import sleep_ms
from math import sqrt

# On utilise l'I2C n°1 de la carte NUCLEO-WB55 pour communiquer avec le capteur
i2c = I2C(1)

# Pause d'une seconde pour laisser à l'I2C le temps de s'initialiser
sleep_ms(1000)

# Instanciation du magnétomètre
magnetometer = lis2mdl.LIS2MDL(i2c)

while True:

	# Lecture du champ magnétique sur les trois axes orthogonaux
	magnetometer.get()
	bx = magnetometer.x()
	by = magnetometer.y()
	bz = magnetometer.z()

	# Affiche les composantes du champ magnétique (entiers signés avec 3 digits)
	print("Composantes du champ magnétique :")
	print(" - Selon l'axe Ox : %6d µT" % bx)
	print(" - Selon l'axe Oy : %6d µT" % by)
	print(" - Selon l'axe Oz : %6d µT" % bz)

	# Calcul du module du champ magnétique
	b = sqrt(bx*bx + by*by + bz*bz)

	# Affiche le module du champ magnétique avec une décimale après la virgule
	print("Intensité du champ magnétique : %.1f µT" % b)
	print("")
	
	# Temporisation
	sleep_ms(1000)
