# Objet du script :
# Mesure la température et la pression toutes les cinq secondes. 
# Rapporte la pression au niveau de la mer sur la base de l'altitude du lieu.
# Cet exemple nécessite un baromètre MEMS LPS22HH.

from machine import I2C # Pilote du bus I2C
import lps22 # Pilote du baromètre
from time import sleep_ms # Pour temporiser

local_elevation = const(470) # en mètres

# Pression rapportée au niveau de la mer
def SeaLevelPressure(pressure, altitude):
	return pressure * pow(1.0 - (altitude * 2.255808707E-5), -5.255)

# On utilise l'I2C n°1 de la carte NUCLEO-WB55 pour communiquer avec le capteur
i2c = I2C(1)

# Pause d'une seconde pour laisser à l'I2C le temps de s'initialiser
sleep_ms(1000)

# Instanciation du capteur
sensor = lps22.LPS22(i2c)

# Instanciation des LED
led_blue = pyb.LED(1)
led_green = pyb.LED(2)
led_red = pyb.LED(3)

while True:

	# Mesure de température
	temp = round(sensor.temperature())
	
	# Mesure de pression
	press = round(SeaLevelPressure(sensor.pressure(),local_elevation))

	print("Température : " + str(temp) + "°C, Pression : " + str(press) + "hPa, ", end = '')

	if temp > 25 :
		led_red.on()
		print("Chaud")
	elif temp > 17 and temp <= 25 :
		led_green.on()
		print("Confortable")
	else:
		led_blue.on()
		print("Froid")

	# Onéteint les LED
	led_red.off()
	led_green.off()
	led_blue.off()

	# Temporisation
	sleep_ms(5000)
